rates = {
    'first_shift': {
        'workweek': 25,
        'weekend': 30
    },
    'second_shift': {
        'workweek': 15,
        'weekend': 20
    },
    'third_shift': {
        'workweek': 20,
        'weekend': 25
    }
}
